utils

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 23, 2019 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetBoolValue

func GetBoolValue(value interface{}) (bool, error)

GetBoolValue will attempt to convert the given value to a bool

func GetFloatValue

func GetFloatValue(value interface{}) (float64, error)

GetFloatValue will attempt to convert the given value to a float64

func GetIntValue

func GetIntValue(value interface{}) (int64, error)

GetIntValue will attempt to convert the given value to an int64

func GetStringValue

func GetStringValue(value interface{}) (string, error)

GetStringValue will attempt to convert the given value to a string

Types

This section is empty.

Jump to